pub fn factorize_simplicial_symbolic_cholesky_scratch<I: Index>( n: usize, ) -> StackReq
computes the size and alignment of the workspace required to compute the symbolic cholesky factorization of a square matrix with size n
n