prefactorize_symbolic_cholesky_scratch

Function prefactorize_symbolic_cholesky_scratch 

pub fn prefactorize_symbolic_cholesky_scratch<I: Index>(
    n: usize,
    nnz: usize,
) -> StackReq
computes the size and alignment of the workspace required to compute the elimination tree and column counts of a matrix of size n with nnz non-zero entries