pub struct EliminationTreeRef<'a, I: Index> { /* private fields */ }Expand description
reference to a slice containing the cholesky factor’s elimination tree
the elimination tree (or elimination forest, in the general case) is a structure representing the relationship between the columns of the cholesky factor, and the way how earlier columns contribute their sparsity pattern to later columns of the factor
Implementations
Sourceimpl<'a, I: Index> EliminationTreeRef<'a, I>
impl<'a, I: Index> EliminationTreeRef<'a, I>
Sourcepub fn into_inner(self) -> &'a [I::Signed]
pub fn into_inner(self) -> &'a [I::Signed]
returns the raw elimination tree
a value can be either nonnegative to represent the index of the parent of a given node,
or -1 to signify that it has no parent
Sourcepub unsafe fn from_inner(inner: &'a [I::Signed]) -> Self
pub unsafe fn from_inner(inner: &'a [I::Signed]) -> Self
creates an elimination tree reference from the underlying array
safety
the elimination tree must come from an array that was previously filled with
prefactorize_symbolic_cholesky