pub struct SymbolicSimplicialCholesky<I> { /* private fields */ }Expand description
cholesky factor structure containing its symbolic structure
Implementations
Sourceimpl<I: Index> SymbolicSimplicialCholesky<I>
impl<I: Index> SymbolicSimplicialCholesky<I>
Sourcepub fn len_val(&self) -> usize
pub fn len_val(&self) -> usize
returns the length of the slice that can be used to contain the numerical values of the cholesky factor
Sourcepub fn factor(&self) -> SymbolicSparseColMatRef<'_, I>
pub fn factor(&self) -> SymbolicSparseColMatRef<'_, I>
returns the cholesky factor’s symbolic structure
Sourcepub fn solve_in_place_scratch<T>(&self, rhs_ncols: usize) -> StackReq
pub fn solve_in_place_scratch<T>(&self, rhs_ncols: usize) -> StackReq
returns the size and alignment of the workspace required to solve the system $A x = rhs$