pub fn factorize_simplicial_numeric_ldlt<I: Index, T: ComplexField>(
L_values: &mut [T],
A: SparseColMatRef<'_, I, T>,
regularization: LdltRegularization<'_, T::Real>,
symbolic: &SymbolicSimplicialCholesky<I>,
stack: &mut MemStack,
) -> Result<LdltInfo, LdltError>Expand description
computes the numeric values of the cholesky $LDL^H$ factors of the matrix $A$, and stores
them in l_values
note
only the upper triangular part of $A$ is accessed
panics
the symbolic structure must be computed by calling
factorize_simplicial_symbolic_cholesky on a matrix with the same symbolic structure
otherwise, the behavior is unspecified and panics may occur